﻿using System;
using System.Drawing;
using System.Text;

namespace MarkusGrothoff.Media {

    /// <summary>
    /// Stellen Player dar, die Videos wiedergeben können.
    /// </summary>
    public class VideoPlayer : MediaPlayer {

        /// <summary>
        /// Erstellt einen neuen Videoplayer.
        /// </summary>
        /// <param name="handle">Control-Handle für die Darstellung von Videos.</param>
        public VideoPlayer(IntPtr displayHandle) : base(displayHandle) { }

        /// <summary>
        /// Erstellt einen neuen Videoplayer.
        /// </summary>
        public VideoPlayer() : base() { }

        /// <summary>
        /// Ruft die Position des Videos ab.
        /// </summary>
        /// <exception cref="InvalidOperationException">Keine Datei geöffnet.</exception>
        /// <exception cref="MediaException">Der Befehl konnte nicht ausgeführt werden.</exception>
        public Point Location {
            get {
                if (!IsOpen) {
                    throw new InvalidOperationException("No file is opened.");
                } else {
                    StringBuilder returnString = new StringBuilder(1024);
                    int result = MciApi.SendString("where " + Alias + " destination", returnString,
                        returnString.Capacity, CallbackHandle);
                    if (result != 0) {
                        throw CreateMciException(result);
                    } else {
                        String[] value = returnString.ToString().Split(' ');
                        return new Point(int.Parse(value[0]), int.Parse(value[1]));
                    }
                }
            }
        }

        /// <summary>
        /// Ruft die Größe des Videos ab.
        /// </summary>
        /// <exception cref="InvalidOperationException">Keine Datei geöffnet.</exception>
        /// <exception cref="MediaException">Der Befehl konnte nicht ausgeführt werden.</exception>
        public Size Size {
            get {
                if (!IsOpen) {
                    throw new InvalidOperationException("No file is opened.");
                } else {
                    StringBuilder returnString = new StringBuilder(1024);
                    int result = MciApi.SendString("where " + Alias + " destination", returnString,
                        returnString.Capacity, CallbackHandle);
                    if (result != 0) {
                        throw CreateMciException(result);
                    } else {
                        String[] value = returnString.ToString().Split(' ');
                        return new Size(int.Parse(value[2]), int.Parse(value[3]));
                    }
                }
            }
        }
    }
}